fn held_grade(attainment: Option<&SuotarAttainment>) -> Option<String>Expand description
The registry’s own grade for an attainment, with its scale named: “1” is a pass on one scale and a one out of five on the other.
fn held_grade(attainment: Option<&SuotarAttainment>) -> Option<String>The registry’s own grade for an attainment, with its scale named: “1” is a pass on one scale and a one out of five on the other.